# Vertical Cross-Section of a Reverse Fault with Splay (2D)

The files are in the directory `examples/reverse-2d`.
The files and directories for this set of examples includes:

:`README.md`: README file containing a brief description of the various examples.
:`*.cfg`: PyLith parameter files.
:`generate_gmsh.py`: Python script to generate mesh using Gmsh.
:`*.msh`: Gmsh mesh files generated by Gmsh.
:`*.jou`: Files used to construct the finite-element mesh using CUBIT/Trelis.
:`*.exo`: Exodus II mesh files generated by Cubit.
:`*.spatialdb`: Spatial database filesFiles associated with the spatial databases.
:`viz`: Directory containing ParaView Python scripts and other files for visualizing results.
:`output`: Directory containing simulation output. It is created automatically when running the simulations.

## Overview

This suite of examples demonstrates use of a number of features for a vertical cross section of a reverse fault accompanied by a splay fault ({numref}`fig:example:reverse:2d:geometry`) with elastic and viscoelastic material properties.
We separately consider loading from gravitational body forces, surface tractions, and coseismic slip.
We build on the previous examples and add complexity through a series of steps:

:Step 1: Gravitational body forces and linear isotropic elasticity.
:Step 2: Gravitational body forces and linear isotropic elasticity with a reference stress state.
:Step 3: Gravitational body forces and linear isotropic incompressible elasticity.
:Step 4: Surface tractions and linear isotropic linear elasticity.
:Step 5: Earthquake rupture on one fault and linear isotropic linear elasticity.
:Step 6: Earthquake rupture on two faults and linear isotropic linear elasticity.
:Step 7: Earthquake rupture on two faults and linear isotropic Maxwell viscoelastic rheology.
:Step 8: Earthquake rupture on two faults and linear isotropic powerlaw viscoelastic rheology.

:::{figure-md} fig:example:reverse:2d:geometry
<img src="figs/geometry.*" alt="Geometry used for 2D reverse fault example." width="100%"/>

Diagram of geometry for domain with reverse and splay faults and three materials (crust, slab, and wedge).
The domain extends from -100 km to +100 km in the x direction and from -100 km to 0 in the y direction.
We refer to the domain boundaries using the names shown in the diagram.
:::

:::{important}
We decribe how to generate the finite-element mesh using both Gmsh and Cubit.
The files for both methods are included.
We use the Gmsh files in the PyLith parameter files.
See [examples/strikeslip-2d/step01_slip_cubit.cfg](../strikeslip-2d/step01-slip.md) for a description of how to modify the parameter files to switch from using mesh files from Gmsh to mesh files from Cubit.
:::

## Example Workflow

:::{toctree}
meshing-gmsh.md
meshing-cubit.md
common-information.md
step01-gravity.md
step02-gravity-refstate.md
step03-gravity-incompressible.md
step04-surfload.md
step05-onefault.md
step06-twofaults-elastic.md
step07-twofaults-maxwell.md
step08-twofaults-powerlaw.md
exercises.md
:::
