# Vertical Cross-Section of Subduction Zone (2D)

The files are in the directory `examples/subduction-2d`.
The files and directories for this set of examples includes:

:`README.md`: README file containing a brief description of the various examples.
:`*.cfg`: PyLith parameter files.
:`generate_gmsh.py`: Python script to generate mesh using Gmsh.
:`*.msh`: Gmsh mesh files generated by Gmsh.
:`*.jou`: Files used to construct the finite-element mesh using CUBIT/Trelis.
:`*.exo`: Exodus II mesh files generated by Cubit.
:`*.spatialdb`: Spatial database filesFiles associated with the spatial databases.
:`viz`: Directory containing ParaView Python scripts and other files for visualizing results.
:`output`: Directory containing simulation output. It is created automatically when running the simulations.

## Overview

This example examines quasistatic interseismic and coseismic deformation in 2D for a subduction zone (see {numref}`fig:example:subduction:2d:cartoon`).
It is based on the 2011 M9.0 Tohoku-oki earthquake off the east coast of Japan.
We build on the previous examples and add complexity through a series of steps:

:Step 1: Static coseismic slip on the subduction interface.
:Step 2: Quasistatic interseismic deformation with creep on the top and bottom of the slab, except in the zone of coseismic slip.
:Step 3: Quasistatic earthquake cycle with prescribed coseismic slip and creep.

:::{warning}
Steps 4-6 have not yet been updated for PyLith v3.
:::

:::{figure-md} fig:example:subduction:2d:cartoon
<img src="figs/cartoon.*" alt="Cartoon of subduction zone example." width="75%"/>

Diagram of 2D subduction zone example.
:::

:::{figure-md} fig:example:subduction:2d:geometry
<img src="figs/geometry.*" alt="Geometry of subduction zone example." width="100%"/>

Geometry of the 2D subduction zone example.
The domain extends from -600 km to +600 km in the x direction and from -340 km to 0 in the y direction.
We refer to the domain boundaries using the names shown in the diagram.
:::

:::{important}
We decribe how to generate the finite-element mesh using both Gmsh and Cubit.
The files for both methods are included.
We use the Gmsh files in the PyLith parameter files.
See [examples/strikeslip-2d/step01_slip_cubit.cfg](../strikeslip-2d/step01-slip.md) for a description of how to modify the parameter files to switch from using mesh files from Gmsh to mesh files from Cubit.
:::

## Example Workflow

:::{toctree}
meshing-gmsh.md
meshing-cubit.md
common-information.md
step01-coseismic.md
step02-interseismic.md
step03-eqcycle.md
exercises.md
:::
